@@ -178,3 +178,10 @@ class STFServer(object):
                 return app_info.split(" ")[0].split(":")[1]
         return None
 
+    def get_android_device_ip(self, serial):
+        try:
+            data = self.requests_stf('user/device/getwifiip?serial=' + serial)
+            return data.get('ip', None)
+        except Exception:
+            logger.error('Failed to get android device ip: {}'.format(serial))
+            return None
